@@ -240,7 +240,7 @@ class TagBase(object):
                 raise ValueError("Required id for %r but id was None" % (self,))
             attrs['id'] = self.id
         if xml_file is None:
-            elt = etree.Element(self.tag_name, **attrs)
+            elt = etree.Element(self.tag_name, attrs)
             if self.text:
                 elt.text = self.text
             return elt
